@@ -24,4 +24,4 @@
 # *
 # **************************************************************************
 
-from .run import main
+__version__ = '2.1'
