@@ -99,14 +99,19 @@ class Page1(QWizardPage):
         label_path = QLabel('Path')
         label_pipeline = QLabel('Run pipeline in')
         label_picker = QLabel('Particle picker')
-        label_diam = QLabel('Particle diameter (A)')
-        label_diam.setToolTip(help_picker)
+        label_model = QLabel('Trained model for picking')
+        label_diam = QLabel('Particle size (A)')
+        label_sym = QLabel('Symmetry')
+        label_3d = QLabel('Run 3D steps?')
 
         vbox.addWidget(label_soft, alignment=Qt.Alignment())
         vbox.addWidget(label_path, alignment=Qt.Alignment())
         vbox.addWidget(label_pipeline, alignment=Qt.Alignment())
         vbox.addWidget(label_picker, alignment=Qt.Alignment())
+        vbox.addWidget(label_model, alignment=Qt.Alignment())
         vbox.addWidget(label_diam, alignment=Qt.Alignment())
+        vbox.addWidget(label_sym, alignment=Qt.Alignment())
+        vbox.addWidget(label_3d, alignment=Qt.Alignment())
 
         return vbox
 
@@ -139,7 +144,7 @@ class Page1(QWizardPage):
 
         button_browse = QPushButton('Browse')
         button_browse.setToolTip(help_message)
-        button_browse.clicked.connect(lambda: self.browseSlot(self.rawPath))
+        button_browse.clicked.connect(lambda: self.browseFolderSlot(self.rawPath))
 
         hbox_path.addWidget(self.rawPath, alignment=Qt.Alignment())
         hbox_path.addWidget(button_browse, alignment=Qt.Alignment())
@@ -165,79 +170,75 @@ class Page1(QWizardPage):
         hbox_picker.setAlignment(Qt.AlignLeft)
         btgroup_picker = QButtonGroup()
 
-        self.button_cryolo = self.addRadioButton("crYOLO", default=DEF_PICKER == "crYOLO")
+        self.button_cryolo = self.addRadioButton("crYOLO", default=DEF_PICKER == "Cryolo")
         self.button_topaz = self.addRadioButton("Topaz", default=DEF_PICKER == "Topaz")
-        self.button_logpick = self.addRadioButton("LogPicker", default=DEF_PICKER == "LogPicker")
-
+        self.button_log = self.addRadioButton("LoG", default=DEF_PICKER == "Log")
         btgroup_picker.addButton(self.button_cryolo)
         btgroup_picker.addButton(self.button_topaz)
-        btgroup_picker.addButton(self.button_logpick)
+        btgroup_picker.addButton(self.button_log)
         btgroup_picker.buttonClicked.connect(lambda: self.updPicker(btgroup_picker))
         hbox_picker.addWidget(self.button_cryolo, alignment=Qt.Alignment())
         hbox_picker.addWidget(self.button_topaz, alignment=Qt.Alignment())
-        hbox_picker.addWidget(self.button_logpick, alignment=Qt.Alignment())
+        hbox_picker.addWidget(self.button_log, alignment=Qt.Alignment())
         grid.addLayout(hbox_picker)
 
+        # picker model box
+        hbox_model = QHBoxLayout()
+        self.modelPath = QLineEdit()
+        self.modelPath.setMinimumWidth(300)
+        self.modelPath.setReadOnly(True)
+        self.modelPath.setToolTip(help_message2)
+
+        button_browse = QPushButton('Browse')
+        button_browse.setToolTip(help_message)
+        button_browse.clicked.connect(lambda: self.browseFileSlot(self.modelPath))
+
+        hbox_model.addWidget(self.modelPath, alignment=Qt.Alignment())
+        hbox_model.addWidget(button_browse, alignment=Qt.Alignment())
+        grid.addLayout(hbox_model)
+
         # size box
         hbox_diam = QHBoxLayout()
-        self.label_diamMin = QLabel('')
-        self.label_diamMin.setToolTip(help_picker)
-        hbox_diam.addWidget(self.label_diamMin)
-
-        self.spbox_diamMin = QSpinBox()
-        self.spbox_diamMin.setToolTip(help_picker)
-        self.spbox_diamMin.setRange(0, 9999)
-        self.spbox_diamMin.setValue(LOGPICKER_SIZES[0] if DEF_PICKER != "crYOLO" else 0)
-        self.spbox_diamMin.setFixedSize(60, 25)
-        hbox_diam.addWidget(self.spbox_diamMin)
-
-        self.label_diamMax = QLabel('max')
-        self.label_diamMax.setToolTip(help_picker)
-        self.label_diamMax.setVisible(self.button_logpick.isChecked())
-        hbox_diam.addWidget(self.label_diamMax)
-
-        self.spbox_diamMax = QSpinBox()
-        self.spbox_diamMax.setToolTip(help_picker)
-        self.spbox_diamMax.setVisible(self.button_logpick.isChecked())
-        self.spbox_diamMax.setRange(10, 9999)
-        self.spbox_diamMax.setValue(LOGPICKER_SIZES[1])
-        self.spbox_diamMax.setFixedSize(60, 25)
-        hbox_diam.addWidget(self.spbox_diamMax)
+        self.spbox_diam = QSpinBox()
+        self.spbox_diam.setRange(10, 9999)
+        self.spbox_diam.setValue(DEF_PARTICLE_SIZE)
+        self.spbox_diam.setFixedSize(60, 25)
+        hbox_diam.addWidget(self.spbox_diam)
         hbox_diam.setAlignment(Qt.AlignLeft)
         grid.addLayout(hbox_diam)
 
+        # symmetry box
+        hbox_sym = QHBoxLayout()
+        self.symm = QLineEdit()
+        self.symm.setMinimumWidth(60)
+        self.symm.setMaximumWidth(60)
+        self.symm.setText(DEF_SYMMETRY)
+        hbox_sym.addWidget(self.symm, alignment=Qt.AlignLeft)
+        grid.addLayout(hbox_sym)
+
+        # run 3D steps?
+        hbox_3d = QHBoxLayout()
+        hbox_3d.setAlignment(Qt.AlignLeft)
+        self.do_3d = QCheckBox()
+        hbox_3d.addWidget(self.do_3d, alignment=Qt.Alignment())
+        grid.addLayout(hbox_3d)
+
         return grid
 
     def updSoftware(self, btgroup):
         bt = btgroup.checkedButton()
-        App.model.setSoftware(bt.text())
+        App.model.software = bt.text()
 
     def updPipeline(self, btgroup):
         bt = btgroup.checkedButton()
-        App.model.setPipeline(bt.text())
+        App.model.pipeline = bt.text()
 
     def updPicker(self, btgroup):
         bt = btgroup.checkedButton()
-        if self.button_cryolo.isChecked():  # crYOLO
-            self.label_diamMin.setText("")
-            self.spbox_diamMin.setValue(0)
-            self.label_diamMax.setVisible(False)
-            self.spbox_diamMax.setVisible(False)
-        elif self.button_topaz.isChecked():  # Topaz
-            self.label_diamMin.setText("")
-            self.spbox_diamMin.setValue(LOGPICKER_SIZES[0])
-            self.label_diamMax.setVisible(False)
-            self.spbox_diamMax.setVisible(False)
-        elif self.button_logpick.isChecked():  # LogPicker
-            self.label_diamMin.setText("min")
-            self.spbox_diamMin.setValue(LOGPICKER_SIZES[0])
-            self.label_diamMax.setVisible(True)
-            self.spbox_diamMax.setVisible(True)
+        App.model.picker = bt.text()
+        App.model.size = self.spbox_diam.value()
 
-        App.model.setPicker(bt.text())
-        App.model.setSize(self.spbox_diamMin.value(), self.spbox_diamMax.value())
-
-    def browseSlot(self, var):
+    def browseFolderSlot(self, var):
         """ Called when "Browse" is pressed. """
         folder = METADATA_PATH if var.text() is None else var.text()
         path = QFileDialog.getExistingDirectory(self, "Select Directory",
@@ -246,40 +247,50 @@ class Page1(QWizardPage):
         if path:
             self.refreshPath(path)
 
+    def browseFileSlot(self, var):
+        """ Called when "Browse" is pressed. """
+        file = "" if var.text() is None else var.text()
+        path = QFileDialog.getOpenFileName(self, "Select model file",
+                                           file,
+                                           filter="Pretrained picking model (*.h5 *.sav)")
+        if path:
+            self.refreshModel(path[0])
+
     def refreshPath(self, path):
         """ Update line widget with selected path. """
-        App.model.setMdPath(path)
-        self.rawPath.setText(App.model.getMdPath())
+        App.model.mdPath = path
+        self.rawPath.setText(App.model.mdPath)
+
+    def refreshModel(self, path):
+        """ Update line widget with selected path. """
+        App.model.pickerModel = path
+        self.modelPath.setText(App.model.pickerModel)
 
     def validatePage(self):
         """ Executed when Next is pressed.
         Returns True or False. """
-        App.model.setSize(self.spbox_diamMin.value(), self.spbox_diamMax.value())
+        App.model.symmetry = self.symm.text()
+        App.model.size = self.spbox_diam.value()
+        App.model.run3dsteps = self.do_3d.isChecked()
 
-        if App.model.getMdPath() is None:
-            App.model.setMdPath(METADATA_PATH)
+        if App.model.mdPath is None:
+            App.model.mdPath = METADATA_PATH
 
-        username, uid = getUsername(App.model.getMdPath())
-        App.model.setUser(username, uid)
+        username, uid = getUsername()
+        App.model.user = (username, uid)
 
         if DEBUG:
-            print("\n\nInput params: ",
-                  [App.model.getSoftware(),
-                   App.model.getMdPath(),
-                   App.model.getUser(),
-                   App.model.getPipeline(),
-                   App.model.getPicker(),
-                   App.model.getSize()])
+            print("\n\nInput params: ", sorted(App.model.__dict__.items()))
 
-        prog = App.model.getSoftware()
+        prog = App.model.software
         fnList = App.model.guessFn(prog)
 
         if fnList is None:
             App.showDialog("ERROR", "No matching files found!\n\n" + help_message)
             return False
         else:
-            print("\nFiles found: %s\n" % fnList)
-            App.model.setFn(fnList)
+            print("\nFile found: %s\n" % fnList)
+            App.model.fn = fnList
             return True
 
     def reset(self):
@@ -287,7 +298,8 @@ class Page1(QWizardPage):
         App.model.acqDict.clear()
         App.model.__init__()
         # keep the old path until updated
-        App.model.setMdPath(self.rawPath.text())
+        App.model.mdPath = self.rawPath.text()
+        App.model.pickerModel = self.modelPath.text()
 
     def addRadioButton(self, choice, default=False):
         """ Util func to add QRadioButton widget. """
@@ -307,29 +319,28 @@ class Page2(QWizardPage):
         self.mainLayout = QGridLayout()
         self.mainLayout.addWidget(self.group1(), 0, 0)
         self.mainLayout.addWidget(self.group2(), 0, 1)
-        self.doCalcBox = False
         self.setLayout(self.mainLayout)
 
     def initializePage(self):
         # executed before showing page 2
         acqDict = App.model.acqDict
-        prog = App.model.getSoftware()
-        fnList = App.model.getFn()
+        prog = App.model.software
+        fnList = App.model.fn
 
-        if prog == 'EPU':
-            App.model.parseImgEpu(fnList)
-        else:  # SerialEM
-            App.model.parseImgSem(fnList)
+        App.model.parseMetadata(fnList)
 
         self.addPtclSizeWidgets(acqDict)
         App.model.calcDose()
         App.model.guessDataDir()
 
-        self.setSubTitle("Found the following metadata from %s session:" % prog)
+        msg = f"Found the following metadata from {prog} session: {App.model.mdPath.split('/')[-1]}"
+        if 'Warning' in acqDict:
+            msg += "\n%s" % acqDict['Warning']
+        self.setSubTitle(msg)
 
         scopeID = acqDict['MicroscopeID']
         time = round(float(acqDict['ExposureTime']), 3)
-        dosepf = round(float(acqDict['DosePerFrame']), 2)
+        dosepf = round(float(acqDict['DosePerFrame']), 3)
         px = round(float(acqDict['PixelSpacing']), 4)
 
         self.scope_name.setText(SCOPE_DICT[scopeID][0])
@@ -344,7 +355,7 @@ class Page2(QWizardPage):
             self.vpp.setChecked(False)
 
         self.camera_name.setText(acqDict['Detector'])
-        self.mode.setText(acqDict['Mode'])
+        self.mode.setText("%s, bin %s" % (acqDict['Mode'], acqDict['Binning']))
         self.time.setText(str(time))
         self.frames.setText(acqDict['NumSubFrames'])
         self.dosepf.setText(str(dosepf))
@@ -384,7 +395,7 @@ class Page2(QWizardPage):
         mode = QLabel("Mode")
         time = QLabel("Exposure time (s)")
         frames = QLabel("Frames")
-        dosepf = QLabel("Dose per frame (e/A²)")
+        dosepf = QLabel("Fluence per frame (e/A²)")
         gain = QLabel("Gain reference")
         defects = QLabel("Defects file")
 
@@ -435,40 +446,35 @@ class Page2(QWizardPage):
         return groupBox
 
     def addPtclSizeWidgets(self, acqDict):
-        """ Add particle size widgets depending on the input params. """
-        picker = App.model.getPicker()
-        sizes = App.model.getSize()
-        acqDict['PtclSizes'] = sizes
-        acqDict['Picker'] = picker
-
-        if picker == 'crYOLO' and sizes[0] == 0:
-            pass  # automated estimation, no params needed
-        else:
-            self.doCalcBox = True
-            App.model.calcBox(picker)
-            self.mainLayout.addWidget(self.group3(), 1, 0)
-            self.box.setText(acqDict['BoxSize'])
-            self.mask.setText(acqDict['MaskSize'])
-            self.box_bin.setText(acqDict['BoxSizeSmall'])
+        """ Add particle size widgets. """
+        size = App.model.size
+        acqDict['PtclSize'] = size
+        App.model.calcBox()
+        self.mainLayout.addWidget(self.group3(), 1, 0)
+        self.box.setText(acqDict['BoxSize'])
+        self.mask.setText(acqDict['MaskSize'])
+        self.box_bin.setText(acqDict['BoxSizeSmall'])
 
     def onFinish(self):
         """ Finish is pressed, we need to update all editable vars. """
-        App.model.acqDict['User'] = App.model.getUser()
-        App.model.acqDict['DosePerFrame'] = self.dosepf.text()
-        App.model.acqDict['PixelSpacing'] = self.px.text()
-        App.model.acqDict['PhasePlateUsed'] = self.vpp.isChecked()
-
-        if self.doCalcBox:
-            App.model.acqDict['BoxSize'] = self.box.text()
-            App.model.acqDict['MaskSize'] = self.mask.text()
-            App.model.acqDict['BoxSizeSmall'] = self.box_bin.text()
+        App.model.acqDict.update({
+            'User': App.model.user,
+            'DosePerFrame': self.dosepf.text(),
+            'PixelSpacing': self.px.text(),
+            'PhasePlateUsed': self.vpp.isChecked(),
+            'BoxSize': self.box.text(),
+            'MaskSize': self.mask.text(),
+            'BoxSizeSmall': self.box_bin.text(),
+            'Picker': App.model.picker,
+            'Symmetry': App.model.symmetry
+        })
 
         print("\nFinal parameters:\n")
         for k, v in sorted(App.model.acqDict.items()):
             print(k, v)
         print('\n')
 
-        if App.model.getPipeline() == 'Relion':
+        if App.model.pipeline == 'Relion':
             setupRelion(App.model.acqDict)
         else:
             setupScipion(App.model.acqDict)
