@@ -29,7 +29,7 @@ from watchdog.observers.polling import PollingObserver as Observer
 from watchdog.events import RegexMatchingEventHandler
 
 from .config import *
-from .utils.misc import getUsername, setParticleSizes
+from .utils.misc import getUsername
 from .parser import Parser
 from .schedule import setupRelion, setupScipion
 
@@ -71,33 +71,28 @@ def start_app(mdFn):
     else:
         mdPath = "/".join(mdFn.split("/")[:-1])
     model = Parser()
-    model.setSoftware(DEF_SOFTWARE)
-    model.setPipeline(DEF_PIPELINE)
-    model.setMdPath(mdPath)
-    model.setFn(mdFn)
+    model.software = DEF_SOFTWARE
+    model.pipeline = DEF_PIPELINE
+    model.picker = DEF_PICKER
+    model.size = DEF_PARTICLE_SIZE
+    model.symmetry = DEF_SYMMETRY
+    model.mdPath = mdPath
+    model.fn = mdFn
 
-    username, uid = getUsername(mdPath)
-    model.setUser(username, uid)
-    model.acqDict['User'] = model.getUser()
+    username, uid = getUsername()
+    model.user = (username, uid)
+    model.acqDict['User'] = username
 
     if DEBUG:
-        print("\n\nInput params: ",
-              model.getSoftware(),
-              model.getMdPath(),
-              model.getUser(),
-              model.getPipeline())
+        print("\n\nInput params: ", sorted(model.__dict__.items()))
 
-    print("\nFiles found: %s\n" % mdFn)
-
-    if DEF_SOFTWARE == 'EPU':
-        model.parseImgEpu(mdFn)
-    else:  # SerialEM
-        model.parseImgSem(mdFn)
+    print("\nFile found: %s\n" % mdFn)
 
+    model.parseMetadata(mdFn)
     model.calcDose()
     model.guessDataDir(wait=True)
-    model.acqDict['Picker'] = DEF_PICKER
-    setParticleSizes(model)
+    model.acqDict['PtclSize'] = DEF_PARTICLE_SIZE
+    model.calcBox()
 
     print("\nFinal parameters:\n")
     for k, v in sorted(model.acqDict.items()):
